import { GraphQLString, GraphQLBoolean } from "graphql"
import { mutationWithClientMutationId } from "graphql-relay"
import { ShowType } from "../show"
import { ResolverContext } from "types/graphql"

export default mutationWithClientMutationId<any, any, ResolverContext>({
  name: "FollowShow",
  description: "Follow (or unfollow) a show",
  inputFields: {
    partnerShowID: {
      type: GraphQLString,
    },
    unfollow: {
      type: GraphQLBoolean,
      defaultValue: false,
    },
  } /*
  FIXME: Generated by the snake_case to camelCase codemod.
         Either use this to fix inputs and/or remove this comment.
  {
    const {
      partnerShowID,
      ..._newFields
    } = newFields;
    const oldFields = {
      partnerShowID: partner_show_id,
      ..._newFields
    };
  }
  */,
  outputFields: {
    show: {
      type: ShowType,
      resolve: ({ partner_show }, _options, { showLoader }) =>
        showLoader(partner_show.id),
    },
  },
  mutateAndGetPayload: (
    { partnerShowID: partner_show_id, unfollow },
    { followShowLoader, unfollowShowLoader }
  ) => {
    if (!followShowLoader || !unfollowShowLoader) {
      throw new Error("Missing Follow Show Loader. Check your access token.")
    }

    const performAction = unfollow
      ? unfollowShowLoader({ partner_show_id })
      : followShowLoader({ partner_show_id })

    return performAction.then((returnValue) => returnValue)
  },
})
