import {
  Boolean,
  Number,
  String,
  Array,
  Record,
  Static,
  Undefined,
  Null,
} from "runtypes"
import { EmbeddedArtist } from "./Artist"
import { EditionSet } from "./EditionSet"
import { Image } from "./Image"
import { CulturalMaker } from "./CulturalMaker"
import { Partner } from "./Partner"

export const Artwork = Record({
  _id: String,
  id: String,
  access: String.Or(Undefined),
  acquireable: Boolean,
  additional_information: String,
  attribution_class: String.Or(Null),
  artist: EmbeddedArtist.Or(Null),
  artists: Array(EmbeddedArtist),
  availability: String,
  blurb: String,
  can_share_image: Boolean,
  can_share: Boolean,
  category: String,
  certificate_of_authenticity: Boolean.Or(Null),
  collecting_institution: String,
  comparables_count: Number,
  condition_description: String.Or(Null),
  cultural_maker: String.Or(Null),
  cultural_makers: Array(CulturalMaker),
  current_version_id: String.Or(Null),
  date: String,
  default_image_id: String.Or(Null),
  deleted_at: String.Or(Null),
  depth_cm: Number.Or(Null),
  depth: String.Or(Null),
  diameter_cm: Number.Or(Null),
  diameter: String.Or(Null),
  dimensions: Record({ in: String.Or(Null), cm: String.Or(Null) }),
  display: String,
  domestic_shipping_fee_cents: Number.Or(Null),
  duration: String.Or(Null),
  ecommerce: Boolean,
  edition_sets: Array(EditionSet),
  edition_sets_count: Number,
  eu_shipping_origin: Boolean,
  exhibition_history: String,
  feature_eligible: Boolean,
  forsale: Boolean,
  framed: Boolean.Or(Null),
  height_cm: Number.Or(Null),
  height: String.Or(Null),
  images: Array(Image),
  image_rights: String,
  inquireable: Boolean,
  international_shipping_fee_cents: Number.Or(Null),
  last_saved_at: String.Or(Null),
  literature: String,
  manufacturer: String.Or(Null),
  medium: String,
  metric: String.Or(Null),
  not_signed: Boolean.Or(Null),
  offer: Boolean,
  offerable: Boolean,
  offerable_from_inquiry: Boolean,
  partner: Partner,
  pickup_available: Boolean.Or(Null),
  price_cents: Array(Number.Or(Null)).Or(Null),
  price_currency: String.Or(Null),
  price_hidden: Boolean,
  price_includes_tax: Boolean,
  price: String,
  provenance: String,
  published_at: String,
  published: Boolean,
  publisher: String.Or(Null),
  relevant_auction_results: String,
  recent_saves_count: String.Or(Null),
  sale_ids: Array(String),
  sale_message: String.Or(Null),
  series: String.Or(Null),
  shipping_origin: Array(String).Or(Null),
  signature: String,
  signed_by_artist: Boolean.Or(Null),
  signed_in_plate: Boolean.Or(Null),
  signed_other: Boolean.Or(Null),
  size_score: Number.Or(Null),
  sold: Boolean,
  stamped_by_artist_estate: Boolean.Or(Null),
  sticker_label: Boolean.Or(Null),
  tags: Array(String),
  title: String.Or(Null),
  unique: Boolean,
  website: String,
  width_cm: Number.Or(Null),
  width: String.Or(Null),
})

export type Artwork = Static<typeof Artwork>
